import * as basicValidation from "./basicValidation.cjs";
/**
 * This function validates the inputs of a GET request on /auth
 */
export function validateGetAuthInput(parameters) {
    if (parameters) {
        if (!basicValidation.validateAuthorizationRequest(parameters["Authorization"])
            && parameters['Authorization'] !== undefined) {
            validateGetAuthInput.errors = basicValidation.validateAuthorizationRequest.errors;
            return false;
        }
        if (!basicValidation.validateXRealIPRequest(parameters["X-Real-IP"])
            && parameters['X-Real-IP'] !== undefined) {
            validateGetAuthInput.errors = basicValidation.validateXRealIPRequest.errors;
            return false;
        }
        if (!basicValidation.validateXForwardedProtoRequest(parameters["X-Forwarded-Proto"])
            && parameters['X-Forwarded-Proto'] !== undefined) {
            validateGetAuthInput.errors = basicValidation.validateXForwardedProtoRequest.errors;
            return false;
        }
    }
    else {
        if (parameters !== undefined) {
            return false;
        }
    }
    return true;
}
/**
 * This function validates the outputs to a GET request on /auth
 */
export function validateGetAuthOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (response.headers) {
            if (!basicValidation.validateGetAuthHeaderXRequestAuthenticationResponse(response.headers["XRequestAuthentication"])
                && response.headers['XRequestAuthentication'] !== undefined) {
                validateGetAuthOutput.errors = basicValidation.validateGetAuthHeaderXRequestAuthenticationResponse.errors;
                return false;
            }
        }
        else {
            if (response.headers !== undefined) {
                return false;
            }
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateGetAuthOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a POST request on /login
 */
export function validatePostLoginInput(body) {
    if (!basicValidation.validatePostLoginRequestBodyRequest(body)) {
        validatePostLoginInput.errors = basicValidation.validatePostLoginRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a POST request on /login
 */
export function validatePostLoginOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 201) {
        if (!basicValidation.validatePostLoginResponse201Response(response.body)) {
            validatePostLoginOutput.errors = basicValidation.validatePostLoginResponse201Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePostLoginOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a POST request on /logout
 */
export function validatePostLogoutInput(body) {
    if (!basicValidation.validatePostLogoutRequestBodyRequest(body)) {
        validatePostLogoutInput.errors = basicValidation.validatePostLogoutRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a POST request on /logout
 */
export function validatePostLogoutOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 204) {
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePostLogoutOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a GET request on /users
 */
export function validateGetUsersInput(parameters) {
    if (parameters) {
        if (!basicValidation.validateUsernameRequest(parameters["username"])
            && parameters['username'] !== undefined) {
            validateGetUsersInput.errors = basicValidation.validateUsernameRequest.errors;
            return false;
        }
    }
    else {
        if (parameters !== undefined) {
            return false;
        }
    }
    return true;
}
/**
 * This function validates the outputs to a GET request on /users
 */
export function validateGetUsersOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetUsersResponse200Response(response.body)) {
            validateGetUsersOutput.errors = basicValidation.validateGetUsersResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateGetUsersOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a POST request on /users
 */
export function validatePostUsersInput(body) {
    if (!basicValidation.validatePostUsersRequestBodyRequest(body)) {
        validatePostUsersInput.errors = basicValidation.validatePostUsersRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a POST request on /users
 */
export function validatePostUsersOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 201) {
        if (!basicValidation.validatePostUsersResponse201Response(response.body)) {
            validatePostUsersOutput.errors = basicValidation.validatePostUsersResponse201Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePostUsersOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a GET request on /users/{user_id}
 */
export function validateGetUsersByUserIdInput(parameters) {
    if (parameters) {
        if (!basicValidation.validateUserIdRequest(parameters["user_id"])) {
            validateGetUsersByUserIdInput.errors = basicValidation.validateUserIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a GET request on /users/{user_id}
 */
export function validateGetUsersByUserIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetUsersByUserIdResponse200Response(response.body)) {
            validateGetUsersByUserIdOutput.errors = basicValidation.validateGetUsersByUserIdResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateGetUsersByUserIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a PATCH request on /users/{user_id}
 */
export function validatePatchUsersByUserIdInput(parameters, body) {
    if (parameters) {
        if (!basicValidation.validateUserIdRequest(parameters["user_id"])) {
            validatePatchUsersByUserIdInput.errors = basicValidation.validateUserIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    if (!basicValidation.validatePatchUsersByUserIdRequestBodyRequest(body)) {
        validatePatchUsersByUserIdInput.errors = basicValidation.validatePatchUsersByUserIdRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a PATCH request on /users/{user_id}
 */
export function validatePatchUsersByUserIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validatePatchUsersByUserIdResponse200Response(response.body)) {
            validatePatchUsersByUserIdOutput.errors = basicValidation.validatePatchUsersByUserIdResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePatchUsersByUserIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a DELETE request on /users/{user_id}
 */
export function validateDeleteUsersByUserIdInput(parameters) {
    if (parameters) {
        if (!basicValidation.validateUserIdRequest(parameters["user_id"])) {
            validateDeleteUsersByUserIdInput.errors = basicValidation.validateUserIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a DELETE request on /users/{user_id}
 */
export function validateDeleteUsersByUserIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 204) {
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateDeleteUsersByUserIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a GET request on /identity
 */
export function validateGetIdentityInput() {
    return true;
}
/**
 * This function validates the outputs to a GET request on /identity
 */
export function validateGetIdentityOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetIdentityResponse200Response(response.body)) {
            validateGetIdentityOutput.errors = basicValidation.validateGetIdentityResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateGetIdentityOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a PATCH request on /identity
 */
export function validatePatchIdentityInput(body) {
    if (body === undefined) {
        return true;
    }
    if (!basicValidation.validatePatchIdentityRequestBodyRequest(body)) {
        validatePatchIdentityInput.errors = basicValidation.validatePatchIdentityRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a PATCH request on /identity
 */
export function validatePatchIdentityOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validatePatchIdentityResponse200Response(response.body)) {
            validatePatchIdentityOutput.errors = basicValidation.validatePatchIdentityResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePatchIdentityOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a POST request on /token
 */
export function validatePostTokenInput(body) {
    if (!basicValidation.validatePostTokenRequestBodyRequest(body)) {
        validatePostTokenInput.errors = basicValidation.validatePostTokenRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a POST request on /token
 */
export function validatePostTokenOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 201) {
        if (!basicValidation.validatePostTokenResponse201Response(response.body)) {
            validatePostTokenOutput.errors = basicValidation.validatePostTokenResponse201Response.errors;
            return false;
        }
        return true;
    }
    validatePostTokenOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
//# sourceMappingURL=requestValidation.js.map