import { HttpError, UnauthorizedError } from '@crosslab/service-common';
import { authenticationSourceFromConfig } from '../authenticationSources/index.js';
import { config } from '../config.js';
import { ApplicationDataSource } from '../database/datasource.js';
import { createNewToken } from '../token/helper.js';
const authenticationProviders = config.AUTHENTICATION_SOURCES.map(authenticationSourceFromConfig);
async function provision(user, req) {
    await req.authorization.relate(`user:${user.uuid}`, 'viewer', 'user');
    return user;
}
export const postLogin = async (req) => {
    const { username, password } = req.body;
    let checkCredentialsResult = { success: false };
    for (const provider of authenticationProviders) {
        checkCredentialsResult = await provider.checkCredentials(username, password);
        if (checkCredentialsResult.success) {
            break;
        }
    }
    if (!checkCredentialsResult.success) {
        throw new UnauthorizedError();
    }
    const { user, needsProvisioning } = checkCredentialsResult;
    user.lastLogin = new Date().toISOString();
    ApplicationDataSource.manager.save(user);
    if (needsProvisioning) {
        provision(user, req);
    }
    const token = await createNewToken(user);
    return { status: 201, body: token };
};
export const postLogout = async () => {
    throw new HttpError(501, 'Not implemented');
};
//# sourceMappingURL=login_logout.js.map